@@ -19,7 +19,8 @@ md = MarkdownIt()
 
 validation_error_lookup = {
     "date-time": mark_safe(
-        'Incorrect date format. Dates should use the form YYYY-MM-DDT00:00:00Z. Learn more about <a href="https://standard.open-contracting.org/latest/en/schema/reference/#date">dates in OCDS</a>.'  # noqa: E501
+        "Incorrect date format. Dates should use the form YYYY-MM-DDT00:00:00Z. Learn more about "
+        '<a href="https://standard.open-contracting.org/latest/en/schema/reference/#date">dates in OCDS</a>.'
     ),
 }
 
@@ -92,13 +93,13 @@ def oneOf_draft4(validator, oneOf, instance, schema):
                 )
                 err.error_id = "releases_both_embedded_and_linked"
                 yield err
-                break
+                return
 
         all_errors.extend(errs)
     else:
         err = ValidationError(
-            "%s is not valid under any of the given schemas"
-            % (json.dumps(instance, sort_keys=True, default=decimal_default),),
+            f"{json.dumps(instance, sort_keys=True, default=decimal_default)} "
+            "is not valid under any of the given schemas",
             context=all_errors,
         )
         err.error_id = "oneOf_any"
@@ -108,7 +109,7 @@ def oneOf_draft4(validator, oneOf, instance, schema):
     if more_valid:
         more_valid.append(first_valid)
         reprs = ", ".join(repr(schema) for schema in more_valid)
-        err = ValidationError("%r is valid under each of %s" % (instance, reprs))
+        err = ValidationError(f"{instance!r} is valid under each of {reprs}")
         err.error_id = "oneOf_each"
         err.reprs = reprs
         yield err
