@@ -406,7 +406,7 @@ def get_bad_ocds_prefixes(json_data):
                 continue
             ocid = release.get("ocid", "")
             if ocid and isinstance(ocid, str) and not prefix_regex.match(ocid):
-                bad_prefixes.append((ocid, "releases/%s/ocid" % n_rel))
+                bad_prefixes.append((ocid, f"releases/{n_rel}/ocid"))
 
     elif records and isinstance(records, list):
         for n_rec, record in enumerate(records):
@@ -414,21 +414,21 @@ def get_bad_ocds_prefixes(json_data):
                 continue
             ocid = record.get("ocid", "")
             if ocid and not prefix_regex.match(ocid):
-                bad_prefixes.append((ocid, "records/%s/ocid" % (n_rec)))
+                bad_prefixes.append((ocid, f"records/{n_rec}/ocid"))
 
             for n_rel, release in enumerate(record.get("releases") or {}):
                 if not isinstance(release, dict):
                     continue
                 ocid = release.get("ocid", "")
                 if ocid and not prefix_regex.match(ocid):
-                    bad_prefixes.append((ocid, "records/%s/releases/%s/ocid" % (n_rec, n_rel)))
+                    bad_prefixes.append((ocid, f"records/{n_rec}/releases/{n_rel}/ocid"))
 
             compiled_release = record.get("compiledRelease", {})
             if compiled_release and isinstance(compiled_release, dict):
                 ocid = compiled_release.get("ocid", "")
                 if ocid and not prefix_regex.match(ocid):
-                    bad_prefixes.append((ocid, "records/%s/compiledRelease/ocid" % n_rec))
-                    bad_prefixes.append((ocid, "records/%s/compiledRelease/ocid" % n_rec))
+                    bad_prefixes.append((ocid, f"records/{n_rec}/compiledRelease/ocid"))
+                    bad_prefixes.append((ocid, f"records/{n_rec}/compiledRelease/ocid"))
 
     return bad_prefixes
 
@@ -439,9 +439,10 @@ def add_conformance_rule_errors(context, json_data, schema_obj):
 
     if ocds_prefixes_bad_format:
         ocid_schema_description = schema_obj.get_schema_obj()["properties"]["ocid"]["description"]
-        ocid_info_index = ocid_schema_description.index("For more information")
+        # XXX: The last sentence is assumed to be a link to guidance in all versions of OCDS.
+        ocid_info_index = ocid_schema_description.rindex(". ") + 1
         ocid_description = ocid_schema_description[:ocid_info_index]
-        ocid_info_url = ocid_schema_description[ocid_info_index:].split("[")[1].split("]")[1][1:-1]
+        ocid_info_url = re.search(r"\((\S+)\)", ocid_schema_description[ocid_info_index:]).group(1)
         context["conformance_errors"] = {
             "ocds_prefixes_bad_format": ocds_prefixes_bad_format,
             "ocid_description": ocid_description,
